@@ -9,6 +9,10 @@ import requests
 from typing import Optional, Dict, Any
 from rich.console import Console
 from rich.table import Table
+try:
+    import humanize as _humanize
+except Exception:
+    _humanize = None
 from rich.progress import Progress, SpinnerColumn, TextColumn
 from rich.live import Live
 from rich.panel import Panel
