@@ -47,7 +47,7 @@ class AuthManager:
         return self._get_api_key_file()
     
     def remove_api_key(self, username: str = "default") -> None:
-        """Remove stored API key"""
+        """Remove stored API key and all authentication data"""
         try:
             keyring.delete_password(self.service_name, username)
         except Exception:
@@ -57,7 +57,11 @@ class AuthManager:
         self._remove_api_key_file()
         # Remove OAuth tokens as well
         self._remove_oauth_tokens()
-        console.print("[green]Credentials removed[/green]")
+        # Remove Clerk session
+        self._remove_clerk_session()
+        # Remove auth token
+        self.remove_auth_token()
+        console.print("[green]All credentials removed[/green]")
     
     def store_oauth_tokens(self, tokens: Dict[str, Any]) -> None:
         """Store OAuth tokens securely with expiration metadata"""
@@ -263,6 +267,122 @@ class AuthManager:
             auth_token_path.chmod(0o600)
         except Exception:
             pass
+
+    def store_clerk_session(self, session_data: Dict[str, Any]) -> None:
+        """Store Clerk session data securely"""
+        # Add metadata for session management
+        enhanced_session = session_data.copy()
+        enhanced_session['stored_at'] = datetime.now().isoformat()
+        
+        # Calculate expiration if provided
+        if 'expires_at' in session_data:
+            # Store as-is if already provided
+            pass
+        elif 'expires_in' in session_data:
+            # Convert expires_in to expires_at
+            expires_in_seconds = int(session_data['expires_in'])
+            expiration_time = datetime.now() + timedelta(seconds=expires_in_seconds)
+            enhanced_session['expires_at'] = expiration_time.isoformat()
+        
+        try:
+            # Store session in keyring
+            session_json = json.dumps(enhanced_session)
+            keyring.set_password(self.service_name, "clerk_session", session_json)
+            console.print("[green]Clerk session stored securely[/green]")
+        except Exception as e:
+            # Fallback to file storage
+            console.print(f"[yellow]Warning: Could not use secure storage ({e})[/yellow]")
+            console.print("[yellow]Falling back to file storage[/yellow]")
+            self._store_clerk_session_file(enhanced_session)
+
+    def get_clerk_session(self) -> Optional[Dict[str, Any]]:
+        """Retrieve stored Clerk session"""
+        try:
+            session_json = keyring.get_password(self.service_name, "clerk_session")
+            if session_json:
+                return json.loads(session_json)
+        except Exception:
+            pass
+        
+        # Fallback to file storage
+        return self._get_clerk_session_file()
+
+    def _store_clerk_session_file(self, session_data: Dict[str, Any]) -> None:
+        """Store Clerk session in file (fallback)"""
+        session_path = self.config.config_dir / "clerk_session.json"
+        session_path.parent.mkdir(parents=True, exist_ok=True)
+        
+        with open(session_path, 'w') as f:
+            json.dump(session_data, f)
+        
+        # Set restrictive permissions
+        session_path.chmod(0o600)
+
+    def _get_clerk_session_file(self) -> Optional[Dict[str, Any]]:
+        """Get Clerk session from file (fallback)"""
+        session_path = self.config.config_dir / "clerk_session.json"
+        
+        if session_path.exists():
+            try:
+                with open(session_path, 'r') as f:
+                    return json.load(f)
+            except Exception:
+                pass
+        
+        return None
+
+    def _remove_clerk_session(self) -> None:
+        """Remove Clerk session"""
+        try:
+            keyring.delete_password(self.service_name, "clerk_session")
+        except Exception:
+            pass
+        
+        # Remove from file storage
+        session_path = self.config.config_dir / "clerk_session.json"
+        if session_path.exists():
+            session_path.unlink()
+
+    def is_clerk_session_expired(self, session: Dict[str, Any]) -> bool:
+        """Check if Clerk session is expired"""
+        if not session:
+            return True
+        
+        # Check if we have expiration metadata
+        if 'expires_at' in session:
+            try:
+                expires_at = datetime.fromisoformat(session['expires_at'])
+                # Consider session expired if it expires within the next 5 minutes
+                buffer_time = timedelta(minutes=5)
+                return datetime.now() + buffer_time >= expires_at
+            except (ValueError, TypeError):
+                pass
+        
+        # Fallback: check if session is older than 1 hour (typical JWT lifetime)
+        if 'stored_at' in session:
+            try:
+                stored_at = datetime.fromisoformat(session['stored_at'])
+                return datetime.now() - stored_at > timedelta(hours=1)
+            except (ValueError, TypeError):
+                pass
+        
+        # If no metadata, assume expired for safety
+        return True
+
+    def get_valid_clerk_session(self) -> Optional[Dict[str, Any]]:
+        """Get valid Clerk session, removing if expired"""
+        session = self.get_clerk_session()
+        
+        if not session:
+            return None
+        
+        # Check if session is expired
+        if self.is_clerk_session_expired(session):
+            # Remove expired session
+            self._remove_clerk_session()
+            return None
+        
+        return session
     
     def get_auth_token(self) -> Optional[str]:
         """Get stored authentication token"""
@@ -289,44 +409,37 @@ class AuthManager:
                 pass
     
     def is_authenticated(self) -> bool:
-        """Check if user is authenticated with valid (non-expired) credentials"""
-        # Check for valid OAuth tokens (with automatic refresh)
-        if self.get_valid_oauth_tokens() is not None:
-            return True
+        """Check if user is authenticated with valid credentials.
         
-        # Check for API key
-        if self.get_api_key() is not None:
+        Prefers JWT auth if present; falls back to API key authentication.
+        """
+        # Prefer stored JWT token if available
+        if self.get_auth_token():
             return True
-        
-        # Check for JWT token
-        if self.get_auth_token() is not None:
-            return True
-        
-        return False
+        # Fallback to API key
+        return self.get_api_key() is not None
     
     def get_auth_headers(self) -> Dict[str, str]:
-        """Get authentication headers for API requests"""
-        headers = {}
+        """Get authentication headers for API requests.
         
-        # Try OAuth tokens first (with automatic refresh)
-        oauth_tokens = self.get_valid_oauth_tokens()
-        if oauth_tokens and oauth_tokens.get('access_token'):
-            token_type = oauth_tokens.get('token_type', 'Bearer')
-            headers["Authorization"] = f"{token_type} {oauth_tokens['access_token']}"
+        If a JWT auth token is stored, use it. Otherwise use API key.
+        """
+        headers: Dict[str, str] = {}
+        
+        # Prefer dedicated stored JWT
+        jwt_token = self.get_auth_token()
+        if jwt_token:
+            headers["Authorization"] = f"Bearer {jwt_token}"
             return headers
-        
-        # Try API key next
+        # Next, prefer OAuth access token if present and valid
+        oauth_tokens = self.get_valid_oauth_tokens()
+        if oauth_tokens and oauth_tokens.get("access_token"):
+            headers["Authorization"] = f"Bearer {oauth_tokens['access_token']}"
+            return headers
+        # Finally, fallback to API key
         api_key = self.get_api_key()
         if api_key:
             headers["Authorization"] = f"Bearer {api_key}"
-            return headers
-        
-        # Fall back to JWT token
-        token = self.get_auth_token()
-        if token:
-            headers["Authorization"] = f"Bearer {token}"
-            return headers
-        
         return headers
     
     def prompt_for_api_key(self) -> Optional[str]:
