@@ -27,9 +27,9 @@ class Config:
         
         # Default configuration
         self.defaults = {
-            # Use a stable, proxied domain by default; can be overridden via env or config
-            "api_url": "https://api.ivybiosciences.com/api/v1",
-            "frontend_url": "https://ivybiosciences.com",
+            # Use frontend domain for API calls to avoid SSL issues and enable Clerk auth
+            "api_url": "https://www.ivybiosciences.com/api/v1",
+            "frontend_url": "https://www.ivybiosciences.com",
             "timeout": 30,
             "output_format": "json",
             "theme": "light",
